********
Django Magic Notifier
********
A notifications library for Djangonauts


Why Django Magic Notifier?
-------------

Sending notifications in Django has always been a complex subject. Django Magic Notifier solves this by
providing only one function `notify()`

Installation
------------

``$pip install --upgrade django-magic-notifier``

Features
--------
    - Send emails
    - Sens sms
    - Send push messages
    - Support custom EmailClient
    - Support custom SmsClient

Usage
-----
.. code-block:: python

    django-admin startproject testbot
    cd testbot
    python manage.py startapp base

Docs and support
----------------
You can find the documentation at https://django-magic-notifier.readthedocs.org

Roadmap
-------
    - Write all tests
    - Generate full documentation
    - Translate documentation

Contributing
------------
Contribution are welcome and required.

License
-------
As per the license, feel free to use the the framework as you want.